@@ -269,7 +269,7 @@ class GtkLanguageSelector(LanguageSelectorBase):
         else:
             self.window_main.set_sensitive(False)
             if win:
-                win.set_cursor(Gdk.Cursor.new(Gdk.CursorType.WATCH))
+                win.set_cursor(Gdk.Cursor(Gdk.CursorType.WATCH))
         while Gtk.events_pending():
             Gtk.main_iteration()
 
@@ -945,7 +945,7 @@ class GtkLanguageSelector(LanguageSelectorBase):
                 "close and re-open Language Support.") % mylocale + ' ]')
             return
         self.label_example_currency.set_text(locale.currency(20457.99, grouping=True))
-        self.label_example_number.set_text(locale.format("%.2f", 1234567.89, grouping=True))
+        self.label_example_number.set_text(locale.format_string("%.2f", 1234567.89, grouping=True))
         self.label_example_date.set_text(time.strftime(locale.nl_langinfo(locale.D_T_FMT)))
 
 
